﻿// Create STEP-NC Program using C# and Forms
// ========================================
//
// This C# project calls the STEP-NC API using the .NET interface.  It
// creates a dialog and button which creates a small machining program
// with a few toolpath moves.
//
// You can find more examples and other programming documentation at:
//
//	http://www.steptools.com/support/
//

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using STEPNCLib;

namespace $safeprojectname$
{
    public partial class Form1 : Form
    {
	public Form1()
	{
	    InitializeComponent();
	}

	private void button1_Click(object sender, EventArgs e)
	{
	    // ReadSTEPNC() to read existing data
	    // MakeSTEPNC() to create new data

	    Close(); // done
	}

	private void ReadSTEPNC()
	{
	    Finder finder = new Finder();
	    Adaptive ctl = new Adaptive();

	    // Read a STEP-NC file
	    finder.Open238("C:/Program Files (x86)/STEP Tools/STEP-NC Machine/examples/boxy_renton_signed.stpnc");

	    // Start traversing the process within the file.   Uses the active data from finder.
	    ctl.StartProject();

	    // Select only workplan start/stop, and individual workingsteps
	    ctl.SetWantedAll(false);
	    ctl.SetWanted(Adaptive.CtlEvent.EXEC_WORKPLAN_START);
	    ctl.SetWanted(Adaptive.CtlEvent.EXEC_WORKPLAN_END);
	    ctl.SetWanted(Adaptive.CtlEvent.OPERATION_START);

	    while (ctl.Next() != Adaptive.CtlEvent.DONE)
	    {
		long id;
		switch (ctl.Event())
		{
		    case Adaptive.CtlEvent.EXEC_WORKPLAN_START:
			id = ctl.GetActiveWorkplan();
			//Console.WriteLine("STARTING WORKPLAN #{0} [{1}]", id, finder.GetExecutableName(id));
			break;
		    case Adaptive.CtlEvent.EXEC_WORKPLAN_END:
			//Console.WriteLine("ENDING WORKPLAN #{0}",ctl.GetActiveWorkplan());
 			break;

		    case Adaptive.CtlEvent.OPERATION_START:
			id = ctl.GetActiveExec(); 
			//Console.WriteLine("STARTING OPERATION #{0} (workstep #{1}) [{2}]", 
			// ctl.GetActiveOperation(), id, finder.GetExecutableName(id));		
			break;

		    default:
			//Console.WriteLine("UNEXPECTED EVENT");
 			break;

		}
	    }
	}

	private void MakeSTEPNC()
	{
	    // Create a trivial STEP-NC file
	    AptStepMaker apt = new AptStepMaker();
	    apt.PartNo("test part");
	    apt.DefineTool(0.25, 5.0, 1.0, 2.0, 3.0, 4.0, 5.0);
	    apt.LoadTool(1);
	    apt.Rapid();
	    apt.GoToXYZ("point001", 1.0, 12.0, 0.0);
	    apt.GoToXYZ("point002", 1.0, 14.0, 0.0);
	    apt.SaveAsModules("test");
	}
    }
}
